@@ -17,7 +17,7 @@
 #define APP_OS KERNEL_NAME
 #define APP_OS_LC KERNEL_NAME_LC
 #define SB_PLUGIN_NAME "Vagalume Status Bar Plugin"
-#define SB_PLUGIN_NAME_LC "vagalume-sb-plugin"
+#define SB_PLUGIN_NAME_LC "vgl-sb-plugin"
 #define SB_PLUGIN_VERSION VERSION
 
 #define APP_FULLNAME APP_NAME " " APP_VERSION " (" APP_OS "/" ARCH ")"
