@@ -9,6 +9,7 @@
 #include <libxml/parser.h>
 #include <string.h>
 #include <stdlib.h>
+#include <glib/gi18n.h>
 
 #include "http.h"
 #include "util.h"
@@ -17,7 +18,7 @@
 
 static const char *handshake_url =
        "http://ws.audioscrobbler.com/radio/handshake.php"
-       "?version=" LASTFM_APP_VERSION "&platform=" APP_OS_LC;
+       "?version=1.5&platform=" APP_OS_LC;
 static const char *custom_pls_path =
        "/1.0/webclient/getresourceplaylist.php";
 static const xmlChar *free_track_rel = (xmlChar *)
@@ -174,7 +175,7 @@ lastfm_session_new(const char *username, const char *password,
  */
 static gboolean
 lastfm_parse_track(xmlDoc *doc, xmlNode *node, LastfmPls *pls,
-                   const char *pls_title, gboolean custom_pls)
+                   const char *pls_title)
 {
         g_return_val_if_fail(doc!=NULL && node!=NULL && pls!=NULL, FALSE);
 
@@ -182,8 +183,8 @@ lastfm_parse_track(xmlDoc *doc, xmlNode *node, LastfmPls *pls,
         const xmlChar *name;
         char *val;
         LastfmTrack *track = lastfm_track_new();
-        track->pls_title = g_strdup(pls_title);
-        track->custom_pls = custom_pls;
+        track->pls_title =
+                g_strdup (pls_title ? pls_title : _("(unknown radio)"));
 
         while (node != NULL) {
                 name = node->name;
@@ -266,7 +267,8 @@ lastfm_parse_track(xmlDoc *doc, xmlNode *node, LastfmPls *pls,
  * @return A new playlist, or NULL if none was found
  */
 static LastfmPls *
-lastfm_parse_playlist(const char *buffer, size_t bufsize)
+lastfm_parse_playlist (const char *buffer, size_t bufsize,
+                       const char *default_pls_title)
 {
         xmlDoc *doc = NULL;
         xmlNode *node = NULL;
@@ -274,7 +276,6 @@ lastfm_parse_playlist(const char *buffer, size_t bufsize)
         LastfmPls *pls = NULL;
         const xmlChar *name;
         char *pls_title = NULL;
-        gboolean custom_pls = FALSE;
         g_return_val_if_fail(buffer != NULL && bufsize > 0, NULL);
 
         doc = xmlParseMemory(buffer, bufsize);
@@ -301,8 +302,6 @@ lastfm_parse_playlist(const char *buffer, size_t bufsize)
                         xmlFree((xmlChar *)title);
                 } else if (!xmlStrcmp(name, (const xmlChar *) "trackList")) {
                         tracklist = node;
-                } else if (!xmlStrcmp(name, (const xmlChar *) "allflp")) {
-                        custom_pls = TRUE;
                 }
                 node = node->next;
         }
@@ -313,10 +312,13 @@ lastfm_parse_playlist(const char *buffer, size_t bufsize)
                 g_warning("No tracks found in playlist");
                 node = NULL;
         }
+        if (pls_title == NULL) {
+                pls_title = g_strdup (default_pls_title);
+        }
         while (node != NULL) {
                 if (!xmlStrcmp(node->name, (const xmlChar *) "track")) {
                         lastfm_parse_track(doc, node->xmlChildrenNode, pls,
-                                           pls_title, custom_pls);
+                                           pls_title);
                 }
                 node = node->next;
         }
@@ -333,10 +335,12 @@ lastfm_parse_playlist(const char *buffer, size_t bufsize)
  * Request a new playlist from the currently active radio.
  * @param s The session
  * @param discovery Whether to use discovery mode or not
+ * @param pls_title Playlist title to use if no name is found in the response.
  * @return A new playlist or NULL if none has been obtained
  */
 LastfmPls *
-lastfm_request_playlist(LastfmSession *s, gboolean discovery)
+lastfm_request_playlist (LastfmSession *s, gboolean discovery,
+                         const char *pls_title)
 {
         g_return_val_if_fail(s && s->id && s->base_url && s->base_path, NULL);
         const char *disc_mode = discovery ? "1" : "0";
@@ -347,10 +351,10 @@ lastfm_request_playlist(LastfmSession *s, gboolean discovery)
 
         url = g_strconcat("http://", s->base_url, s->base_path,
                           "/xspf.php?sk=", s->id, "&discovery=", disc_mode,
-                          "&desktop=" LASTFM_APP_VERSION, NULL);
+                          "&desktop=1.5", NULL);
         http_get_buffer(url, &buffer, &bufsize);
         if (buffer != NULL) {
-                pls = lastfm_parse_playlist(buffer, bufsize);
+                pls = lastfm_parse_playlist (buffer, bufsize, pls_title);
                 g_free(buffer);
         }
         g_free(url);
@@ -375,10 +379,10 @@ lastfm_request_custom_playlist(LastfmSession *s, const char *radio_url)
         char *radio_url_escaped = escape_url(radio_url, TRUE);
         url = g_strconcat("http://", s->base_url, custom_pls_path,
                           "?sk=", s->id, "&url=", radio_url_escaped,
-                          "&desktop=" LASTFM_APP_VERSION, NULL);
+                          "&desktop=1.5", NULL);
         http_get_buffer(url, &buffer, &bufsize);
         if (buffer != NULL) {
-                pls = lastfm_parse_playlist(buffer, bufsize);
+                pls = lastfm_parse_playlist (buffer, bufsize, NULL);
                 g_free(buffer);
         }
         g_free(url);
@@ -391,15 +395,17 @@ lastfm_request_custom_playlist(LastfmSession *s, const char *radio_url)
  * tracks from this radio.
  * @param s The session
  * @param radio_url URL of the radio to set
+ * @param pls_title If non-NULL, the playlist title will be stored there.
  * @return Whether the radio has been set correctly
  */
 gboolean
-lastfm_set_radio(LastfmSession *s, const char *radio_url)
+lastfm_set_radio (LastfmSession *s, const char *radio_url, char **pls_title)
 {
         g_return_val_if_fail(s != NULL && s->id != NULL &&
                              s->base_url != NULL &&
                              s->base_path && radio_url != NULL, FALSE);
         char *buffer = NULL;
+        char *title = NULL;
         gboolean retval = FALSE;
         char *url;
         char *radio_url_escaped = escape_url(radio_url, TRUE);
@@ -413,12 +419,20 @@ lastfm_set_radio(LastfmSession *s, const char *radio_url)
         g_free(radio_url_escaped);
 
         if (buffer != NULL) {
-                if (g_strrstr(buffer, "OK")) {
-                        retval = TRUE;
-                }
+                GHashTable *ht = lastfm_parse_handshake (buffer);
+                const char *response = g_hash_table_lookup (ht, "response");
+                retval = g_str_equal (response, "OK");
+                title = g_strdup (g_hash_table_lookup (ht, "stationname"));
+                g_hash_table_destroy (ht);
         }
         g_free(buffer);
 
+        if (pls_title != NULL) {
+                *pls_title = title;
+        } else {
+                g_free (title);
+        }
+
         return retval;
 }
 
