@@ -13,17 +13,22 @@
 #include "metadata.h"
 #include "util.h"
 
-#include <gtk/gtk.h>
-#if defined(MAEMO2) || defined(MAEMO3)
-#include <hildon-widgets/hildon-program.h>
-#include <hildon-widgets/hildon-banner.h>
-#include <hildon-widgets/hildon-file-chooser-dialog.h>
-#elif defined(MAEMO4)
-#include <hildon/hildon-program.h>
-#include <hildon/hildon-banner.h>
-#include <hildon/hildon-file-chooser-dialog.h>
-#endif
 #include <string.h>
+#include <gtk/gtk.h>
+
+#if defined(HILDON_LIBS)
+#        include <hildon-widgets/hildon-program.h>
+#        include <hildon-widgets/hildon-banner.h>
+#elif defined(HILDON_1)
+#        include <hildon/hildon-program.h>
+#        include <hildon/hildon-banner.h>
+#endif
+
+#if defined(HILDON_FM)
+#        include <hildon-widgets/hildon-file-chooser-dialog.h>
+#elif defined(HILDON_FM_2)
+#        include <hildon/hildon-file-chooser-dialog.h>
+#endif
 
 static void tagwin_selcombo_changed(GtkComboBox *combo, gpointer data);
 
@@ -38,7 +43,7 @@ typedef struct {
         GtkEntry *entry;
         GtkComboBox *selcombo;
         GtkComboBox *globalcombo;
-        lastfm_track *track;
+        LastfmTrack *track;
         char *user;
         char *tags_artist;
         char *tags_track;
@@ -195,6 +200,70 @@ ui_input_dialog(GtkWindow *parent, const char *title,
         return retvalue;
 }
 
+gboolean
+ui_edit_bookmark_dialog(GtkWindow *parent, char **name, char **url,
+                        gboolean add)
+{
+        GtkDialog *dialog;
+        GtkWidget *namelabel, *urllabel;
+        GtkEntry *nameentry, *urlentry;
+        GtkBox *vbox;
+        gboolean done, retvalue;
+        dialog = ui_base_dialog(parent,
+                                add ? _("Add bookmark") : _("Edit bookmark"));
+        namelabel = gtk_label_new(_("Bookmark name"));
+        urllabel = gtk_label_new(_("Last.fm radio address"));
+        nameentry = GTK_ENTRY(gtk_entry_new());
+        urlentry = GTK_ENTRY(gtk_entry_new());
+
+        if (*name != NULL) gtk_entry_set_text(nameentry, *name);
+        if (*url != NULL) gtk_entry_set_text(urlentry, *url);
+
+        vbox = GTK_BOX (dialog->vbox);
+        gtk_box_pack_start(vbox, namelabel, FALSE, FALSE, 4);
+        gtk_box_pack_start(vbox, GTK_WIDGET(nameentry), FALSE, FALSE, 4);
+        gtk_box_pack_start(vbox, urllabel, FALSE, FALSE, 4);
+        gtk_box_pack_start(vbox, GTK_WIDGET(urlentry), FALSE, FALSE, 4);
+        gtk_entry_set_activates_default(nameentry, TRUE);
+        gtk_entry_set_activates_default(urlentry, TRUE);
+        gtk_widget_show_all(GTK_WIDGET(dialog));
+        done = FALSE;
+        while (!done) {
+                if (gtk_dialog_run(dialog) == GTK_RESPONSE_ACCEPT) {
+                        char *tmpname, *tmpurl;
+                        tmpname = g_strdup(gtk_entry_get_text(nameentry));
+                        tmpurl = g_strdup(gtk_entry_get_text(urlentry));
+                        g_strstrip(tmpname);
+                        g_strstrip(tmpurl);
+                        if (tmpname[0] == '\0') {
+                                ui_info_dialog(GTK_WINDOW(dialog),
+                                               _("Invalid bookmark name"));
+                                gtk_widget_grab_focus(GTK_WIDGET(nameentry));
+                        } else if (strncmp(tmpurl, "lastfm://", 9)) {
+                                ui_info_dialog(GTK_WINDOW(dialog),
+                                               _("Last.fm radio URLs must "
+                                                 "start with lastfm://"));
+                                gtk_widget_grab_focus(GTK_WIDGET(urlentry));
+                        } else {
+                                retvalue = done = TRUE;
+                                g_free(*name);
+                                g_free(*url);
+                                *name = tmpname;
+                                *url = tmpurl;
+                        }
+                        if (!done) {
+                                g_free(tmpname);
+                                g_free(tmpurl);
+                        }
+                } else {
+                        retvalue = FALSE;
+                        done = TRUE;
+                }
+        }
+        gtk_widget_destroy(GTK_WIDGET(dialog));
+        return retvalue;
+}
+
 static char *
 ui_select_download_dir(GtkWindow *parent, const char *curdir)
 {
@@ -263,7 +332,7 @@ usercfg_user_pw_modified(GObject *obj, GParamSpec *arg, usercfgwin *win)
 }
 
 static void
-usercfg_add_account_settings(usercfgwin *win, lastfm_usercfg *cfg)
+usercfg_add_account_settings(usercfgwin *win, VglUserCfg *cfg)
 {
         g_return_if_fail(win != NULL && GTK_IS_NOTEBOOK(win->nb));
         GtkTable *table;
@@ -330,7 +399,7 @@ usercfg_add_account_settings(usercfgwin *win, lastfm_usercfg *cfg)
 }
 
 static void
-usercfg_add_connection_settings(usercfgwin *win, lastfm_usercfg *cfg)
+usercfg_add_connection_settings(usercfgwin *win, VglUserCfg *cfg)
 {
         g_return_if_fail(win != NULL && GTK_IS_NOTEBOOK(win->nb));
         GtkTable *table;
@@ -369,7 +438,7 @@ usercfg_add_connection_settings(usercfgwin *win, lastfm_usercfg *cfg)
 }
 
 static void
-usercfg_add_download_settings(usercfgwin *win, lastfm_usercfg *cfg)
+usercfg_add_download_settings(usercfgwin *win, VglUserCfg *cfg)
 {
         g_return_if_fail(win != NULL && GTK_IS_NOTEBOOK(win->nb));
         GtkTable *table;
@@ -406,7 +475,7 @@ usercfg_add_download_settings(usercfgwin *win, lastfm_usercfg *cfg)
 }
 
 static void
-usercfg_add_imstatus_settings(usercfgwin *win, lastfm_usercfg *cfg)
+usercfg_add_imstatus_settings(usercfgwin *win, VglUserCfg *cfg)
 {
 #ifdef SET_IM_STATUS
         g_return_if_fail(win != NULL && GTK_IS_NOTEBOOK(win->nb));
@@ -466,7 +535,7 @@ usercfg_add_imstatus_settings(usercfgwin *win, lastfm_usercfg *cfg)
 }
 
 static void
-usercfg_add_misc_settings(usercfgwin *win, lastfm_usercfg *cfg)
+usercfg_add_misc_settings(usercfgwin *win, VglUserCfg *cfg)
 {
         g_return_if_fail(win != NULL && GTK_IS_NOTEBOOK(win->nb));
         GtkTable *table;
@@ -541,15 +610,15 @@ usercfg_add_misc_settings(usercfgwin *win, lastfm_usercfg *cfg)
 }
 
 gboolean
-ui_usercfg_window(GtkWindow *parent, lastfm_usercfg **cfg)
+ui_usercfg_window(GtkWindow *parent, VglUserCfg **cfg)
 {
         g_return_val_if_fail(cfg != NULL, FALSE);
         change_dir_selected_data *windata;
         gboolean changed = FALSE;
         usercfgwin win;
-        const lastfm_usercfg *origcfg = *cfg;
+        const VglUserCfg *origcfg = *cfg;
 
-        if (*cfg == NULL) *cfg = lastfm_usercfg_new();
+        if (*cfg == NULL) *cfg = vgl_user_cfg_new();
         memset (&win, 0, sizeof(win));
         win.dialog = ui_base_dialog(parent, _("User settings"));
         win.nb = GTK_NOTEBOOK(gtk_notebook_new());
@@ -577,10 +646,10 @@ ui_usercfg_window(GtkWindow *parent, lastfm_usercfg **cfg)
 
         gtk_widget_show_all(GTK_WIDGET(win.dialog));
         if (gtk_dialog_run(win.dialog) == GTK_RESPONSE_ACCEPT) {
-                lastfm_usercfg_set_username(*cfg, gtk_entry_get_text(win.user));
-                lastfm_usercfg_set_password(*cfg, gtk_entry_get_text(win.pw));
-                lastfm_usercfg_set_http_proxy(*cfg, gtk_entry_get_text(win.proxy));
-                lastfm_usercfg_set_download_dir(*cfg,
+                vgl_user_cfg_set_username(*cfg, gtk_entry_get_text(win.user));
+                vgl_user_cfg_set_password(*cfg, gtk_entry_get_text(win.pw));
+                vgl_user_cfg_set_http_proxy(*cfg, gtk_entry_get_text(win.proxy));
+                vgl_user_cfg_set_download_dir(*cfg,
                                                 gtk_entry_get_text(win.dlentry));
                 (*cfg)->enable_scrobbling = gtk_toggle_button_get_active(
                         GTK_TOGGLE_BUTTON(win.scrobble));
@@ -589,7 +658,7 @@ ui_usercfg_window(GtkWindow *parent, lastfm_usercfg **cfg)
                 (*cfg)->use_proxy = gtk_toggle_button_get_active(
                         GTK_TOGGLE_BUTTON(win.useproxy));
 #ifdef SET_IM_STATUS
-                lastfm_usercfg_set_imstatus_template(*cfg,
+                vgl_user_cfg_set_imstatus_template(*cfg,
                                                      gtk_entry_get_text(win.imtemplateentry));
                 (*cfg)->im_pidgin = gtk_toggle_button_get_active(
                         GTK_TOGGLE_BUTTON(win.impidgin));
@@ -612,7 +681,7 @@ ui_usercfg_window(GtkWindow *parent, lastfm_usercfg **cfg)
         } else if (origcfg == NULL) {
                 /* If settings haven't been modified, restore the
                    original pointer if it was NULL */
-                lastfm_usercfg_destroy(*cfg);
+                vgl_user_cfg_destroy(*cfg);
                 *cfg = NULL;
         }
         gtk_widget_destroy(GTK_WIDGET(win.dialog));
@@ -666,7 +735,7 @@ ui_input_dialog_with_list(GtkWindow *parent, const char *title,
 }
 
 static GtkComboBox *
-artist_track_album_selection_combo(const lastfm_track *t)
+artist_track_album_selection_combo(const LastfmTrack *t)
 {
         g_return_val_if_fail(t != NULL, NULL);
         char *text;
@@ -910,7 +979,7 @@ tagwin_tagcombo_changed(GtkComboBox *combo, gpointer data)
 
 gboolean
 tagwin_run(GtkWindow *parent, const char *user, char **newtags,
-           const GList *usertags, lastfm_track *track, request_type *type)
+           const GList *usertags, LastfmTrack *track, request_type *type)
 {
         g_return_val_if_fail(track && type && user && newtags, FALSE);
         tagwin *t;
@@ -1070,7 +1139,7 @@ tagwin_run(GtkWindow *parent, const char *user, char **newtags,
 
 gboolean
 recommwin_run(GtkWindow *parent, char **user, char **message,
-              const GList *friends, const lastfm_track *track,
+              const GList *friends, const LastfmTrack *track,
               request_type *type)
 {
         g_return_val_if_fail(user && message && track && type, FALSE);
